# Functional core
Turn the business logic of Dispatcher._dispatch into a pure function.
Paradigms: 
- strongly typed
- functional
- no side-effecting
- return errors instead of using exceptions for control flow

Reference sample code https://github.com/ncreep/fp-edge-canonical/tree/master/code
Use: https://github.com/pytoolz/toolz
Use: https://github.com/dry-python/returns